#! /usr/bin/perl

# Might be useful to have a table of conversions for various big round
# numbers of units of time, maybe.

# Output units are seconds, hours, days, weeks, years.

$ofmt = "%10.3g ";
$hfmt = "%10s ";
$year = 31556925.9747;
@allsecs = ();

# Given a time duration, output the versions we're interested in.
sub outtime {
    my $in = shift;
    push @allsecs, $in;
    printf "$ofmt", $in;	   # Raw seconds
    printf $ofmt, $in/60;	   # Minutes
    printf $ofmt, $in/3600;	   # Hours
    printf $ofmt, $in/(3600*24);   # Days
    printf $ofmt, $in/(3600*24*7); # Weeks
    printf $ofmt, $in/$year;	   # Celestial years 
    print "\n";
}

# Headings
sub outhead {
    printf $hfmt, "Seconds";
    printf $hfmt, "Minutes";
    printf $hfmt, "Hours";
    printf $hfmt, "Days";
    printf $hfmt, "Weeks";
    printf $hfmt, "Years";
    print "\n";
}

# Simple numbers of seconds
outhead();
outtime(1e3);
outtime(1e4);
outtime(1e5);
outtime(1e6);
outtime(1e7);
outtime(1e8);
outtime(1e9);
outtime(1e10);
outtime(1e11);
outtime(1e12);
outtime(1e13);
outtime(1e14);

# Simple numbers of minutes
print "\n";
outhead();
#outtime(60*10);			# 10 minutes
outtime(60*1e3);	
outtime(60*1e4);	
outtime(60*1e5);	
outtime(60*1e6);	
outtime(60*1e7);	
outtime(60*1e8);	
outtime(60*1e9);	
outtime(60*1e10);	
outtime(60*1e11);	

# Simple numbers of hours
print "\n";
outhead();
outtime(3600*1);		# one hour
outtime(3600*1e1);
outtime(3600*1e2);
outtime(3600*1e3);
outtime(3600*1e4);
outtime(3600*1e5);
outtime(3600*1e6);
outtime(3600*1e7);
outtime(3600*1e8);
outtime(3600*1e9);
outtime(3600*1e10);

# Simple numbers of days
print "\n";
outhead();
outtime(3600*24);		# one day
outtime(3600*24*1e1);
outtime(3600*24*1e2);
outtime(3600*24*1e3);
outtime(3600*24*1e4);
outtime(3600*24*1e5);
outtime(3600*24*1e6);
outtime(3600*24*1e7);
outtime(3600*24*1e8);
outtime(3600*24*1e9);

# Simple numbers of years
print "\n";
outhead();
outtime($year);			# one year
outtime($year*1e1);
outtime($year*1e2);
outtime($year*1e3);
outtime($year*1e4);
outtime($year*1e5);
outtime($year*1e6);

# Variant form using sorted seconds
# Not really sure this is a good idea; looks kind of messy. 
# But it's neatly consistent.
print "\n\n\n";
outhead();
# Need to force numeric comparison in the sort.
foreach $s ( sort {$a <=> $b}  @allsecs ) {
#    print $s, "\n";
    outtime($s);
}
